@@ -174,7 +174,9 @@ gp_fontmap_load (void)
 	/* System map */
 
 	systemmap = NULL;
-	name = g_strdup (DATADIR "/fonts/fontmap3");
+	/* fixme: implement parsing full directory of fontmaps */
+	/* fixme: ${sysconfigdir} */
+	name = g_strdup (DATADIR "/fonts/libgnomeprint-2.0.fontmap");
 	if ((stat (name, &s) == 0) && S_ISREG (s.st_mode) && (systemmap = xmlParseFile (name))) {
 		map->system.name = name;
 		map->system.size = s.st_size;
@@ -182,6 +184,16 @@ gp_fontmap_load (void)
 	} else {
 		g_free (name);
 	}
+	if (!systemmap) {
+		name = g_strdup (DATADIR "/fonts/fontmap3");
+		if ((stat (name, &s) == 0) && S_ISREG (s.st_mode) && (systemmap = xmlParseFile (name))) {
+			map->system.name = name;
+			map->system.size = s.st_size;
+			map->system.mtime = s.st_mtime;
+		} else {
+			g_free (name);
+		}
+	}
 	if (!systemmap) {
 		name = g_strdup (DATADIR "/fonts/fontmap2");
 		if ((stat (name, &s) == 0) && S_ISREG (s.st_mode) && (systemmap = xmlParseFile (name))) {
